@@ -1,19 +1,21 @@
 package shared
 
 import (
-	"context"
 	"errors"
 	"fmt"
 	"net/http"
 	"net/url"
+	"regexp"
+	"sort"
 	"strings"
 	"time"
 
 	"github.com/cli/cli/v2/api"
-	"github.com/cli/cli/v2/internal/ghinstance"
+	"github.com/cli/cli/v2/internal/prompter"
+	"github.com/cli/cli/v2/internal/text"
+	"github.com/cli/cli/v2/pkg/iostreams"
 	"github.com/gabriel-vasile/mimetype"
 	"github.com/shurcooL/githubv4"
-	"github.com/shurcooL/graphql"
 )
 
 type GistFile struct {
@@ -37,6 +39,19 @@ type Gist struct {
 	Owner       *GistOwner           `json:"owner,omitempty"`
 }
 
+func (g Gist) Filename() string {
+	filenames := make([]string, 0, len(g.Files))
+	for fn := range g.Files {
+		filenames = append(filenames, fn)
+	}
+	sort.Strings(filenames)
+	return filenames[0]
+}
+
+func (g Gist) TruncDescription() string {
+	return text.Truncate(100, text.RemoveExcessiveWhitespace(g.Description))
+}
+
 var NotFoundErr = errors.New("not found")
 
 func GetGist(client *http.Client, hostname, gistID string) (*Gist, error) {
@@ -73,7 +88,9 @@ func GistIDFromURL(gistURL string) (string, error) {
 	return "", fmt.Errorf("Invalid gist URL %s", u)
 }
 
-func ListGists(client *http.Client, hostname string, limit int, visibility string) ([]Gist, error) {
+const maxPerPage = 100
+
+func ListGists(client *http.Client, hostname string, limit int, filter *regexp.Regexp, includeContent bool, visibility string) ([]Gist, error) {
 	type response struct {
 		Viewer struct {
 			Gists struct {
@@ -81,6 +98,7 @@ func ListGists(client *http.Client, hostname string, limit int, visibility strin
 					Description string
 					Files       []struct {
 						Name string
+						Text string `graphql:"text @include(if: $includeContent)"`
 					}
 					IsPublic  bool
 					Name      string
@@ -95,23 +113,42 @@ func ListGists(client *http.Client, hostname string, limit int, visibility strin
 	}
 
 	perPage := limit
-	if perPage > 100 {
-		perPage = 100
+	if perPage > maxPerPage {
+		perPage = maxPerPage
 	}
 
 	variables := map[string]interface{}{
-		"per_page":   githubv4.Int(perPage),
-		"endCursor":  (*githubv4.String)(nil),
-		"visibility": githubv4.GistPrivacy(strings.ToUpper(visibility)),
+		"per_page":       githubv4.Int(perPage),
+		"endCursor":      (*githubv4.String)(nil),
+		"visibility":     githubv4.GistPrivacy(strings.ToUpper(visibility)),
+		"includeContent": githubv4.Boolean(includeContent),
 	}
 
-	gql := graphql.NewClient(ghinstance.GraphQLEndpoint(hostname), client)
+	filterFunc := func(gist *Gist) bool {
+		if filter.MatchString(gist.Description) {
+			return true
+		}
+
+		for _, file := range gist.Files {
+			if filter.MatchString(file.Filename) {
+				return true
+			}
+
+			if includeContent && filter.MatchString(file.Content) {
+				return true
+			}
+		}
+
+		return false
+	}
+
+	gql := api.NewClientFromHTTP(client)
 
 	gists := []Gist{}
 pagination:
 	for {
 		var result response
-		err := gql.QueryNamed(context.Background(), "GistList", &result, variables)
+		err := gql.Query(hostname, "GistList", &result, variables)
 		if err != nil {
 			return nil, err
 		}
@@ -121,19 +158,22 @@ pagination:
 			for _, file := range gist.Files {
 				files[file.Name] = &GistFile{
 					Filename: file.Name,
+					Content:  file.Text,
 				}
 			}
 
-			gists = append(
-				gists,
-				Gist{
-					ID:          gist.Name,
-					Description: gist.Description,
-					Files:       files,
-					UpdatedAt:   gist.UpdatedAt,
-					Public:      gist.IsPublic,
-				},
-			)
+			gist := Gist{
+				ID:          gist.Name,
+				Description: gist.Description,
+				Files:       files,
+				UpdatedAt:   gist.UpdatedAt,
+				Public:      gist.IsPublic,
+			}
+
+			if filter == nil || filterFunc(&gist) {
+				gists = append(gists, gist)
+			}
+
 			if len(gists) == limit {
 				break pagination
 			}
@@ -174,3 +214,30 @@ func IsBinaryContents(contents []byte) bool {
 	}
 	return isBinary
 }
+
+func PromptGists(prompter prompter.Prompter, client *http.Client, host string, cs *iostreams.ColorScheme) (gist *Gist, err error) {
+	gists, err := ListGists(client, host, 10, nil, false, "all")
+	if err != nil {
+		return &Gist{}, err
+	}
+
+	if len(gists) == 0 {
+		return &Gist{}, nil
+	}
+
+	var opts = make([]string, len(gists))
+
+	for i, gist := range gists {
+		gistTime := text.FuzzyAgo(time.Now(), gist.UpdatedAt)
+		// TODO: support dynamic maxWidth
+		opts[i] = fmt.Sprintf("%s %s %s", cs.Bold(gist.Filename()), gist.TruncDescription(), cs.Muted(gistTime))
+	}
+
+	result, err := prompter.Select("Select a gist", "", opts)
+
+	if err != nil {
+		return &Gist{}, err
+	}
+
+	return &gists[result], nil
+}
